﻿using System;
using System.Windows;
using System.Windows.Input;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.mediaElement.MediaOpened      += mediaElement_MediaOpened;
            this.mediaElement.MediaEnded       += mediaElement_MediaEnded;
            this.playImage.MouseDown           += playImage_MouseDown;
            this.pauseImage.MouseDown          += pauseImage_MouseDown;
            this.stopImage.MouseDown           += stopImage_MouseDown;
            this.volumeSlider.ValueChanged     += volumeSlider_ValueChanged;
            this.speedRatioSlider.ValueChanged += speedRatioSlider_ValueChanged;
            this.seekToSlider.ValueChanged     += seekToSlider_ValueChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 미디어 엘리먼트 미디어 오픈시 처리하기 - mediaElement_MediaOpened(sender, e)

        /// <summary>
        /// 미디어 엘리먼트 미디어 오픈시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void mediaElement_MediaOpened(object sender, EventArgs e)
        {
            this.seekToSlider.Maximum = this.mediaElement.NaturalDuration.TimeSpan.TotalMilliseconds;
        }

        #endregion
        #region 미디어 엘리먼트 미디어 종료시 처리하기 - mediaElement_MediaEnded(sender, e)

        /// <summary>
        /// 미디어 엘리먼트 미디어 종료시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void mediaElement_MediaEnded(object sender, EventArgs e)
        {
            this.mediaElement.Stop();
        }

        #endregion
        #region 재생 이미지 마우스 DOWN 처리하기 - playImage_MouseDown(sender, e)

        /// <summary>
        /// 재생 이미지 마우스 DOWN 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void playImage_MouseDown(object sender, MouseButtonEventArgs e)
        {
            this.mediaElement.Play();

            SetMediaElementData();
        }

        #endregion
        #region 중지 이미지 마우스 DOWN 처리하기 - pauseImage_MouseDown(sender, e)

        /// <summary>
        /// 중지 이미지 마우스 DOWN 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void pauseImage_MouseDown(object sender, MouseButtonEventArgs e)
        {
            this.mediaElement.Pause();
        }

        #endregion
        #region 중단 이미지 마우스 DOWN 처리하기 - stopImage_MouseDown(sender, e)

        /// <summary>
        /// 중단 이미지 마우스 DOWN 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void stopImage_MouseDown(object sender, MouseButtonEventArgs e)
        {
            this.mediaElement.Stop();
        }

        #endregion
        #region 볼륨 슬라이더 값 변경시 처리하기 - volumeSlider_ValueChanged(sender, e)

        /// <summary>
        /// 볼륨 슬라이더 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void volumeSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            this.mediaElement.Volume = (double)this.volumeSlider.Value;
        }

        #endregion
        #region 속도 비율 슬라이더 값 변경시 처리하기 - speedRatioSlider_ValueChanged(sender, e)

        /// <summary>
        /// 속도 비율 슬라이더 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void speedRatioSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            this.mediaElement.SpeedRatio = (double)this.speedRatioSlider.Value;
        }

        #endregion
        #region 탐색 슬라이더 값 변경시 처리하기 - seekToSlider_ValueChanged(sender, e)

        /// <summary>
        /// 탐색 슬라이더 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void seekToSlider_ValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            TimeSpan timeSpan = new TimeSpan(0, 0, 0, 0, (int)this.seekToSlider.Value);

            this.mediaElement.Position = timeSpan;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Event

        #region 미디어 엘리먼트 데이터 설정하기 - SetMediaElementData()

        /// <summary>
        /// 미디어 엘리먼트 데이터 설정하기
        /// </summary>
        private void SetMediaElementData()
        {
            this.mediaElement.Volume     = (double)this.volumeSlider.Value;
            this.mediaElement.SpeedRatio = (double)this.speedRatioSlider.Value;
        }

        #endregion
    }
}